==> CGAL-6.0-doc_html.tar.xz: doc_html/Arrangement_on_surface_2/examples.js <==
var examples =
[
    [ "Arrangement_on_surface_2/aggregated_insertion.cpp", "Arrangement_on_surface_2_2aggregated_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/algebraic_curves.cpp", "Arrangement_on_surface_2_2algebraic_curves_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/algebraic_segments.cpp", "Arrangement_on_surface_2_2algebraic_segments_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/batched_point_location.cpp", "Arrangement_on_surface_2_2batched_point_location_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/Bezier_curves.cpp", "Arrangement_on_surface_2_2Bezier_curves_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/bgl_dual_adapter.cpp", "Arrangement_on_surface_2_2bgl_dual_adapter_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/bgl_primal_adapter.cpp", "Arrangement_on_surface_2_2bgl_primal_adapter_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/bounded_vertical_decomposition.cpp", "Arrangement_on_surface_2_2bounded_vertical_decomposition_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/circles.cpp", "Arrangement_on_surface_2_2circles_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/circular_arcs.cpp", "Arrangement_on_surface_2_2circular_arcs_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/conics.cpp", "Arrangement_on_surface_2_2conics_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/conic_multiplicities.cpp", "Arrangement_on_surface_2_2conic_multiplicities_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/consolidated_curve_data.cpp", "Arrangement_on_surface_2_2consolidated_curve_data_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/curve_history.cpp", "Arrangement_on_surface_2_2curve_history_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/dcel_extension.cpp", "Arrangement_on_surface_2_2dcel_extension_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/dcel_extension_io.cpp", "Arrangement_on_surface_2_2dcel_extension_io_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/dual_lines.cpp", "Arrangement_on_surface_2_2dual_lines_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/dual_with_data.cpp", "Arrangement_on_surface_2_2dual_with_data_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/edge_insertion.cpp", "Arrangement_on_surface_2_2edge_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/edge_manipulation.cpp", "Arrangement_on_surface_2_2edge_manipulation_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/edge_manipulation_curve_history.cpp", "Arrangement_on_surface_2_2edge_manipulation_curve_history_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/face_extension.cpp", "Arrangement_on_surface_2_2face_extension_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/face_extension_overlay.cpp", "Arrangement_on_surface_2_2face_extension_overlay_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/generic_curve_data.cpp", "Arrangement_on_surface_2_2generic_curve_data_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/global_insertion.cpp", "Arrangement_on_surface_2_2global_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/global_removal.cpp", "Arrangement_on_surface_2_2global_removal_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/incremental_insertion.cpp", "Arrangement_on_surface_2_2incremental_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/io.cpp", "Arrangement_on_surface_2_2io_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/io_curve_history.cpp", "Arrangement_on_surface_2_2io_curve_history_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/isolated_vertices.cpp", "Arrangement_on_surface_2_2isolated_vertices_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/observer.cpp", "Arrangement_on_surface_2_2observer_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/overlay.cpp", "Arrangement_on_surface_2_2overlay_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/overlay_color.cpp", "Arrangement_on_surface_2_2overlay_color_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/overlay_unbounded.cpp", "Arrangement_on_surface_2_2overlay_unbounded_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/point_location.cpp", "Arrangement_on_surface_2_2point_location_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/polylines.cpp", "Arrangement_on_surface_2_2polylines_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/predefined_kernel.cpp", "Arrangement_on_surface_2_2predefined_kernel_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/predefined_kernel_non_intersecting.cpp", "Arrangement_on_surface_2_2predefined_kernel_non_intersecting_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/rational_functions.cpp", "Arrangement_on_surface_2_2rational_functions_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/special_edge_insertion.cpp", "Arrangement_on_surface_2_2special_edge_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/spherical_insert.cpp", "Arrangement_on_surface_2_2spherical_insert_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/unbounded_non_intersecting.cpp", "Arrangement_on_surface_2_2unbounded_non_intersecting_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/unbounded_rational_functions.cpp", "Arrangement_on_surface_2_2unbounded_rational_functions_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/vertical_ray_shooting.cpp", "Arrangement_on_surface_2_2vertical_ray_shooting_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/draw_arr.cpp", "Arrangement_on_surface_2_2draw_arr_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/linear_conics.cpp", "Arrangement_on_surface_2_2linear_conics_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/parabolas.cpp", "Arrangement_on_surface_2_2parabolas_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/ellipses.cpp", "Arrangement_on_surface_2_2ellipses_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/hyperbolas.cpp", "Arrangement_on_surface_2_2hyperbolas_8cpp-example.html", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Arrangement_on_surface_2/examples.js <==
var examples =
[
    [ "Arrangement_on_surface_2/aggregated_insertion.cpp", "Arrangement_on_surface_2_2aggregated_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/algebraic_curves.cpp", "Arrangement_on_surface_2_2algebraic_curves_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/algebraic_segments.cpp", "Arrangement_on_surface_2_2algebraic_segments_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/batched_point_location.cpp", "Arrangement_on_surface_2_2batched_point_location_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/Bezier_curves.cpp", "Arrangement_on_surface_2_2Bezier_curves_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/bgl_dual_adapter.cpp", "Arrangement_on_surface_2_2bgl_dual_adapter_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/bgl_primal_adapter.cpp", "Arrangement_on_surface_2_2bgl_primal_adapter_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/bounded_vertical_decomposition.cpp", "Arrangement_on_surface_2_2bounded_vertical_decomposition_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/circles.cpp", "Arrangement_on_surface_2_2circles_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/circular_arcs.cpp", "Arrangement_on_surface_2_2circular_arcs_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/conics.cpp", "Arrangement_on_surface_2_2conics_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/conic_multiplicities.cpp", "Arrangement_on_surface_2_2conic_multiplicities_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/consolidated_curve_data.cpp", "Arrangement_on_surface_2_2consolidated_curve_data_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/count_and_trace.cpp", "Arrangement_on_surface_2_2count_and_trace_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/curve_history.cpp", "Arrangement_on_surface_2_2curve_history_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/dcel_extension.cpp", "Arrangement_on_surface_2_2dcel_extension_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/dcel_extension_io.cpp", "Arrangement_on_surface_2_2dcel_extension_io_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/dual_lines.cpp", "Arrangement_on_surface_2_2dual_lines_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/dual_with_data.cpp", "Arrangement_on_surface_2_2dual_with_data_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/edge_insertion.cpp", "Arrangement_on_surface_2_2edge_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/edge_manipulation.cpp", "Arrangement_on_surface_2_2edge_manipulation_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/edge_manipulation_curve_history.cpp", "Arrangement_on_surface_2_2edge_manipulation_curve_history_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/face_extension.cpp", "Arrangement_on_surface_2_2face_extension_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/face_extension_overlay.cpp", "Arrangement_on_surface_2_2face_extension_overlay_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/generic_curve_data.cpp", "Arrangement_on_surface_2_2generic_curve_data_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/global_insertion.cpp", "Arrangement_on_surface_2_2global_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/global_removal.cpp", "Arrangement_on_surface_2_2global_removal_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/incremental_insertion.cpp", "Arrangement_on_surface_2_2incremental_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/io.cpp", "Arrangement_on_surface_2_2io_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/io_curve_history.cpp", "Arrangement_on_surface_2_2io_curve_history_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/isolated_vertices.cpp", "Arrangement_on_surface_2_2isolated_vertices_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/observer.cpp", "Arrangement_on_surface_2_2observer_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/overlay.cpp", "Arrangement_on_surface_2_2overlay_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/overlay_color.cpp", "Arrangement_on_surface_2_2overlay_color_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/overlay_unbounded.cpp", "Arrangement_on_surface_2_2overlay_unbounded_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/point_location.cpp", "Arrangement_on_surface_2_2point_location_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/polylines.cpp", "Arrangement_on_surface_2_2polylines_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/predefined_kernel.cpp", "Arrangement_on_surface_2_2predefined_kernel_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/predefined_kernel_non_intersecting.cpp", "Arrangement_on_surface_2_2predefined_kernel_non_intersecting_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/rational_functions.cpp", "Arrangement_on_surface_2_2rational_functions_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/special_edge_insertion.cpp", "Arrangement_on_surface_2_2special_edge_insertion_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/spherical_insert.cpp", "Arrangement_on_surface_2_2spherical_insert_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/unbounded_non_intersecting.cpp", "Arrangement_on_surface_2_2unbounded_non_intersecting_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/unbounded_rational_functions.cpp", "Arrangement_on_surface_2_2unbounded_rational_functions_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/vertical_ray_shooting.cpp", "Arrangement_on_surface_2_2vertical_ray_shooting_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/draw_arr.cpp", "Arrangement_on_surface_2_2draw_arr_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/linear_conics.cpp", "Arrangement_on_surface_2_2linear_conics_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/parabolas.cpp", "Arrangement_on_surface_2_2parabolas_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/ellipses.cpp", "Arrangement_on_surface_2_2ellipses_8cpp-example.html", null ],
    [ "Arrangement_on_surface_2/hyperbolas.cpp", "Arrangement_on_surface_2_2hyperbolas_8cpp-example.html", null ]
];
